@@ -67,6 +67,7 @@ JOB_STATUS_OOM = 'out_of_memory'
 JOB_STATUS_TIMED_OUT = 'timed_out'
 JOB_STATUS_STOPPED = 'stopped'
 JOB_STATUS_UNEXPECTED_STATUS = 'unexpected_status'
+JOB_STATUS_PENDING = 'pending'
 
 JOB_FAIL_STATUSES = [
     JOB_STATUS_ENQUEUED_FAILED,
@@ -79,6 +80,7 @@ JOB_FAIL_STATUSES = [
 
 JOB_VALID_STATUSES = [
     JOB_STATUS_SUCCEEDED,
+    JOB_STATUS_PENDING,
     JOB_STATUS_ENQUEUING,
     JOB_STATUS_RUNNING,
     JOB_STATUS_COMPLETED_WITH_FAILURES,
